==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/ApplicationComponents/pqOMETransferFunctionsPropertyWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqOMETransferFunctionsPropertyWidget.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqOMETransferFunctionsPropertyWidget_h
#define pqOMETransferFunctionsPropertyWidget_h

#include "pqApplicationComponentsModule.h"
#include "pqPropertyWidget.h"
#include <QScopedPointer> // for QScopedPointer

class pqTransferFunctionWidget;

class PQAPPLICATIONCOMPONENTS_EXPORT pqOMETransferFunctionsPropertyWidget : public pqPropertyWidget
{
  Q_OBJECT
  typedef pqPropertyWidget Superclass;

public:
  pqOMETransferFunctionsPropertyWidget(
    vtkSMProxy* proxy, vtkSMPropertyGroup* smgroup, QWidget* parent = 0);
  ~pqOMETransferFunctionsPropertyWidget() override;

  bool event(QEvent* evt) override;

Q_SIGNALS:
  void xrgbPointsChanged();
  void xvmsPointsChanged();

private Q_SLOTS:
  void channelVisibilitiesChanged();
  void stcChanged(pqTransferFunctionWidget* src = nullptr);
  void pwfChanged(pqTransferFunctionWidget* src = nullptr);

private:
  Q_DISABLE_COPY(pqOMETransferFunctionsPropertyWidget);
  class pqInternals;
  QScopedPointer<pqInternals> Internals;
  bool UpdatingProperty = false;

  void setXvmsPoints(int index, const QList<QVariant>& xvms);
  void setXrgbPoints(int index, const QList<QVariant>& xrgb);
};

#endif

==> paraview_5.11.0+dfsg.orig.tar.xz: paraview-5.11.0+dfsg/Qt/ApplicationComponents/pqOMETransferFunctionsPropertyWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:  pqOMETransferFunctionsPropertyWidget.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqOMETransferFunctionsPropertyWidget_h
#define pqOMETransferFunctionsPropertyWidget_h

#include "pqApplicationComponentsModule.h"
#include "pqPropertyWidget.h"
#include <QScopedPointer> // for QScopedPointer

class pqTransferFunctionWidget;

class PQAPPLICATIONCOMPONENTS_EXPORT pqOMETransferFunctionsPropertyWidget : public pqPropertyWidget
{
  Q_OBJECT
  typedef pqPropertyWidget Superclass;

public:
  pqOMETransferFunctionsPropertyWidget(
    vtkSMProxy* proxy, vtkSMPropertyGroup* smgroup, QWidget* parent = nullptr);
  ~pqOMETransferFunctionsPropertyWidget() override;

  bool event(QEvent* evt) override;

Q_SIGNALS:
  void xrgbPointsChanged();
  void xvmsPointsChanged();

private Q_SLOTS:
  void channelVisibilitiesChanged();
  void stcChanged(pqTransferFunctionWidget* src = nullptr);
  void pwfChanged(pqTransferFunctionWidget* src = nullptr);

private: // NOLINT(readability-redundant-access-specifiers)
  Q_DISABLE_COPY(pqOMETransferFunctionsPropertyWidget);
  class pqInternals;
  QScopedPointer<pqInternals> Internals;
  bool UpdatingProperty = false;

  void setXvmsPoints(int index, const QList<QVariant>& xvms);
  void setXrgbPoints(int index, const QList<QVariant>& xrgb);
};

#endif
